@@ -1,5 +1,5 @@
-#  tests for firefox-77.0.1-ha925a31_0 (this is a generated file);
-print('===== testing package: firefox-77.0.1-ha925a31_0 =====');
+#  tests for firefox-79.0-ha925a31_0 (this is a generated file);
+print('===== testing package: firefox-79.0-ha925a31_0 =====');
 print('running run_test.py');
 #  --- run_test.py (begin) ---
 """ test whether firefox is viable with geckodriver and selenium
@@ -63,4 +63,4 @@ if __name__ == "__main__":
             sys.exit(1)
 #  --- run_test.py (end) ---
 
-print('===== firefox-77.0.1-ha925a31_0 OK =====');
+print('===== firefox-79.0-ha925a31_0 OK =====');
